#!/bin/sh
#
# Name: install.sh
# Copyright: (c)Copyright 2009 Hewlett-Packard Development Company, L.P.
#
# Description: Installation script for "hp-fc-enablement" kit in singlepath or multi path modes and fibreutils RPM.
# Possible Values:
#   0 -  success
#   1 -  failure
#  Modification History:
# M. Namazi	21-Jan-2009:	Initial development
# M. Namazi     05-Mar-2009:    updated fiberutils to 3.0-3
# M. Namazi     30-Mar-2009     updating to hp-fc-enab. kit version 1.1-4

# Uncomment the following line for script debug
# set -x

# Variables Declarations
NO_ARGS=0
ARGS=0
VALID=1
ORIGDIR=`pwd`
ARCH=`uname -m`

if [ $ARCH == "i686" ]
then
   ARCH="i386"
else
   if [ $ARCH == "i586" ]
   then
      ARCH="i386"
   fi
fi

# file and location definitions
LOGDIR="/var/log/"
LOGFILE="${LOGDIR}/hpUtil.log"

FIBREUTILNAME="fibreutils-3.0-3.${ARCH}.rpm"
ENABLEMENTKITNAME="hp-fc-enablement-1.1-4.noarch.rpm"

CLEANUP=1
TITLE="Use one of the following options:"

# Functions
#

# print_usage
# Prints the help message
# No args
print_usage () {
   echo "NAME"
   echo ""
   echo -e "$TITLE\n"
   echo "DESCRIPTION"
   echo ""
   echo "Installation script for HP Fibre Channel Enablement Kit"
   echo ""
   echo "OPTIONS"
   echo ""
   echo -e "no flag   default installation of hp-enablemnt kit & fiberUtils"
   echo -e "-s        install or upgrade hp-fc-enablement and fiberUtils kits in single path mode."
   echo -e "-m        install or upgrade hp-fc-enablement and fiberUtils kits in mutlti path mode."
   echo -e "-u        uninstall hp-fc-enablement and fiberUtils kits."
   echo -e "-h        display help"
}

# CleanUp
# Removes all files that were in the tar archive
# No args
CleanUp(){
  for i in $FILELIST
  do
      rm -rfd $i
  done
}

# Read argruments
# Parses the command line options passed to the component
# @args - list of command line arguments
read_args () {
   THEARGS=$*

   # get command line
   if [ $# -eq "$NO_ARGS" ]
   then
      ARGS=1
      VALID=0
      FLAGS=""
   else
         if [ $THEARGS == "-s" ]
         then
	    #echo "Option /s"
            ARGS=1
            VALID=0
            FLAGS="/s"
          else
              if [ $THEARGS == "-m" ]
              then
                 # echo "Option /m"
                 ARGS=1
                 VALID=0
                 FLAGS="/m"
              else
                 if [ $THEARGS == "-u" ]
                 then
                    # echo "Option /u"
                    ARGS=1
                    VALID=0
                    FLAGS="/u"
                 else
                    if [ $THEARGS == "-h" ]
                    then
                       # echo "Option /h"
                       ARGS=1
                       VALID=0
                       print_usage
                       return=0
                       WriteLogFooter
                       exit $return
                     else
                              echo "Bad or missing argument."
                              exit 1
                        fi
              fi
         fi
     fi
   fi
}

# ExecuteInstallCommand
# Executes rmp install, upgrade or uninstall commands.
# No args; Return value for the component will be in $return
ExecuteInstallCommand(){
#execute command line
status=$?

echo "Command returned $status"1>>$LOGFILE 2>>$LOGFILE
if [ "$status" -eq 0 ]   # status is good
then
   if [ "$THEARGS" == "-m" ]
   then
      export HPFCHBAKITMULTIPATH=y
      rpm -Uvh $FIBREUTILNAME
      rpm -Uvh $ENABLEMENTKITNAME
      return=1
   else
      if [ "$THEARGS" == "-s" ]
      then
         export HPFCHBAKITSINGLEPATH=y
         rpm -Uvh $FIBREUTILNAME
         rpm -Uvh $ENABLEMENTKITNAME
         return=1
      else
          if [ "$THEARGS" == "-u" ]
          then
             rpm -e fibreutils 
             rpm -e hp-fc-enablement
             return=1
           else
             if [ "$THEARGS" == "" ]
             then
                rpm -Uvh $FIBREUTILNAME
                rpm -Uvh $ENABLEMENTKITNAME
                return=1
             fi
          fi
      fi
   fi
else
   case $status in
	1)	#no upgrade
	  return=3
        ;;
        2)     #Failed
          return=7
        ;;
        3)
          return=7
        ;;
        4)
          return=7
        ;;
        *)
    esac
fi

}

# WriteLogHeader
# Writes the header to the log file for this session
# No args
WriteLogHeader(){
  # create the log directory if it dose not exist
  if test ! -e $LOGDIR
  then
	mkdir -p $LOGDIR
  fi
 
  echo ""1>>$LOGFILE 2>>$LOGFILE
  echo "TITLE"1>>$LOGFILE 2>>$LOGFILE
  echo "---------------------------"1>>$LOGFILE 2>>$LOGFILE
  echo ""1>>$LOGFILE 2>>$LOGFILE
  echo "Session started:`date`"1>>$LOGFILE 2>>$LOGFILE
  echo ""1>>$LOGFILE 2>>$LOGFILE
}

# WriteLogFooter
# Writers the footer to the log file for this session
# No args
WriteLogFooter(){
  echo ""1>>$LOGFILE 2>>$LOGFILE
  echo "HP-Utility return code:$return"1>>$LOGFILE 2>>$LOGFILE
  echo "Session ended:`date`"1>>$LOGFILE 2>>$LOGFILE
}

# Main script
#

#Start Log file
WriteLogHeader

# Read the command line
echo "Command line passed to component is:\"$*\""1>>$LOGFILE 2>>$LOGFILE
read_args $*

# Validate arguments
if [ $VALID -eq 0 ]
then
   ExecuteInstallCommand
else
   echo "Unimplemented command option entered."1>>$LOGFILE 2>>$LOGFILE
   echo "$USAGE"1>>$LOGFILE 2>>$LOGFILE
   return=4
fi

# clean up
if [ $CLEANUP -eq 1 ]
then
   CleanUp
fi

# Write log file footer
WriteLogFooter

# go back to the original directory
cd $ORIGDIR

# exit
exit $return
